searchData={"items":[{"type":"module","title":"Recordlocator","doc":"`Recordlocator` is a module for generating Recordlocators from integer values and decoding Recordlocators back to the integer value.\n\nA Recordlocator is an alphanumeric representation for an integer value. It uses a 32 character alphabet to encode the integer values. A RecordLocator is shorter than the corresponding integer and easier to read and memorize. You can use it to encode autoincrement primary keys from an database into an human-readable representation for your users.","ref":"Recordlocator.html"},{"type":"function","title":"Recordlocator.decode/1","doc":"Decodes Recordlocator string back into an integer.\nReturns {:ok, integer} for valid Recordlocators and {:error, reason} for invalid characters.","ref":"Recordlocator.html#decode/1"},{"type":"function","title":"Examples - Recordlocator.decode/1","doc":"iex> Recordlocator.decode(\"78G\")\n{:ok, 5325}\n\niex> Recordlocator.decode(\"5E82T\")\n{:ok, 3512345}\n\niex> Recordlocator.decode(\"2\")\n{:ok, 0}\n\niex> Recordlocator.decode(\"ABC\")\n{:error, \"Invalid character in input string: B\"}","ref":"Recordlocator.html#decode/1-examples"},{"type":"function","title":"Recordlocator.decode!/1","doc":"Decodes Recordlocator string back into an integer.\nThrows an ArgumentError if the input string contains invalid characters.","ref":"Recordlocator.html#decode!/1"},{"type":"function","title":"Examples - Recordlocator.decode!/1","doc":"iex> Recordlocator.decode!(\"78G\")\n5325\n\niex> Recordlocator.decode!(\"5E82T\")\n3512345\n\niex> Recordlocator.decode!(\"2\")\n0\n\niex> Recordlocator.decode!(\"ABC\")\n** (ArgumentError) Invalid character in input string: B","ref":"Recordlocator.html#decode!/1-examples"},{"type":"function","title":"Recordlocator.encode/1","doc":"Encodes an integer into a Recordlocator.","ref":"Recordlocator.html#encode/1"},{"type":"function","title":"Examples - Recordlocator.encode/1","doc":"iex> Recordlocator.encode(5325)\n  {:ok, \"78G\"}\n\n  iex> Recordlocator.encode(3512345)\n  {:ok, \"5E82T\"}\n\n  iex> Recordlocator.encode(-1)\n  {:error, \"Input must be a non-negative integer\"}","ref":"Recordlocator.html#encode/1-examples"},{"type":"function","title":"Recordlocator.encode!/1","doc":"Encodes an integer into a Recordlocator.\nThrows an ArgumentError for errors.","ref":"Recordlocator.html#encode!/1"},{"type":"function","title":"Examples - Recordlocator.encode!/1","doc":"iex> Recordlocator.encode!(5325)\n\"78G\"\n\niex> Recordlocator.encode!(3512345)\n\"5E82T\"\n\niex> Recordlocator.encode!(-1)\n** (ArgumentError) Input must be a non-negative integer","ref":"Recordlocator.html#encode!/1-examples"},{"type":"extras","title":"Recordlocator for Elixir","doc":"# Recordlocator for Elixir\n\n**An Elixir module to encode integers into a short and easy to read string and decode the strings back to the initial numbers**\n\nThis is the Elixir equivalent to [go-recordlocator](https://github.com/jakoubek/go-recordlocator), [php-recordlocator](https://github.com/jakoubek/php-recordlocator), [lua-recordlocator](https://github.com/jakoubek/lua-recordlocator), [postgresql-recordlocator](https://github.com/jakoubek/postgresql-recordlocator) and [sqlanywhere-recordlocator](https://github.com/jakoubek/sqlanywhere-recordlocator).\n\nA RecordLocator is an alphanumerical string that represents an integer. This package encodes integers to RecordLocators and decodes RecordLocators back to integers.\n\nA RecordLocator is shorter than the corresponding integer and easier to read and memorize. You can use it to encode autoincrement primary keys from an database into an human-readable representation for your users.","ref":"readme.html"},{"type":"extras","title":"Examples - Recordlocator for Elixir","doc":"- The integer 5,325 encodes to the RecordLocator 78G.\n- The integer 3,512,345 encodes to the RecordLocator 5E82T.\n\nBoth RecordLocators are shorter than their integer equivalent. You can encode more than 33.5 million integers in an 5-char RecordLocator: the largest 5-char RecordLocator, ZZZZZ, represents the integer 33,554,431.\n\nWith 6 chars you can encode integers up to more than 1 billion.","ref":"readme.html#examples"},{"type":"extras","title":"Installation - Recordlocator for Elixir","doc":"The package can be installed by adding `recordlocator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:recordlocator, \"~> 1.0\"}\n  ]\nend\n```\n\nDocumentation is available on [HexDocs](https://hexdocs.pm/recordlocator).","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Recordlocator for Elixir","doc":"Encoding integers to recordlocators:\n\n```elixir\n{:ok, rl} = Recordlocator.encode(5325)\n\nrl\n# => 78G\n\nRecordlocator.encode!(5326)\n# => 78H\n```\n\nDecoding recordlocators back into the integer values:\n\n```elixir\n{:ok, number} = Recordlocator.decode(\"78G\")\n\nnumber\n# => 5325\n\nRecordlocator.decode!(\"78H\")\n# => 5326\n```","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}